@@ -29,11 +29,11 @@ class Customer(Base):
             self.last_name = last_name
             self.phone = phone
             self.risk_action = risk_action
-            self.id = id            
+            self.id = id
         else:
             raise InvalidEmailError
 
-        if meta and not isinstance(meta, dict):
+        if metadata and not isinstance(metadata, dict):
             raise TypeError("meta argument should be a dict")
         else:
             self.metadata = metadata
