@@ -55,7 +55,8 @@ class TransactionsManager(Manager):
             raise ValueError("method argument should be STANDARD, INLINE or INLINE EMBED")
 
         if self.PASS_ON_TRANSACTION_COST:
-            transaction.amount = transaction.full_transaction_cost(transaction.card_locale, self.LOCAL_COST, self.INTL_COST)
+            transaction.amount = transaction.full_transaction_cost(transaction.card_locale,
+                                                                   self.LOCAL_COST, self.INTL_COST)
 
         data = json.JSONDecoder().decode(transaction.to_json())
 
@@ -82,7 +83,7 @@ class TransactionsManager(Manager):
 
         #status = True for a successful connection
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             transaction = Transaction.from_json(data)
             return transaction
         else:
@@ -108,8 +109,8 @@ class TransactionsManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = json.JSONEncoder().encode(content['data'])
-            data_dict = data
+            data_dict = content['data']
+            data = json.dumps(content['data'])
             transaction = Transaction.from_json(data)
             transaction.email = data_dict['customer']['email']
             transaction.authorization_code = data_dict['authorization']['authorization_code']
@@ -117,15 +118,15 @@ class TransactionsManager(Manager):
         else:
             raise APIConnectionFailedError(message)
 
-    def charge_authorization(self, transaction: Transaction):
+    def charge_authorization(self, transaction: Transaction, endpoint='/charge_authorization'):
         data = transaction.to_json()
         headers, _ = self.build_request_args()
 
-        response = requests.post(self.PAYSTACK_URL + self.__endpoint, headers=headers, data=data)
+        response = requests.post(self.PAYSTACK_URL + self.__endpoint + endpoint,
+                                 headers=headers, data=data)
         content = response.content
         content = self.parse_response_content(content)
 
-
         status, message = self.get_content_status(content)
 
         #status = True for a successful connection
@@ -168,18 +169,26 @@ class TransactionsManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            return content['data']
+            data = content['data']
+            for item in data:
+                data_dict = item
+                data = json.dumps(content['data'])
+                transaction = Transaction.from_json(data)
+                transaction.email = data_dict['customer']['email']
+                if data_dict['authorization']:
+                    transaction.authorization_code = data_dict['authorization']['authorization_code']
+                return transaction
         else:
             raise APIConnectionFailedError(message)
 
-    def get_transaction(self, id):
+    def get_transaction(self, transaction_id):
         '''
         Gets transaction with the specified id
         '''
-        headers, data = self.build_request_args()
+        headers, _ = self.build_request_args()
 
         url = self.PAYSTACK_URL + self.__endpoint
-        url += '/%s' % (str(id))
+        url += '/%s' % (str(transaction_id))
         response = requests.get(url, headers=headers)
 
         content = response.content
@@ -188,7 +197,14 @@ class TransactionsManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            return content['data']
+            data_dict = content['data']
+            data = json.dumps(data_dict)
+            transaction = Transaction.from_json(data)
+            transaction.email = data_dict['customer']['email']
+            if data_dict['authorization']:
+                transaction.authorization_code = data_dict['authorization']['authorization_code']
+            return transaction
+
         else:
             raise APIConnectionFailedError(message)
 
@@ -275,7 +291,7 @@ class CustomersManager(Manager):
             meta = content['meta']
             customers = []
             for item in data:
-                item = json.JSONEncoder().encode(item)
+                item = json.dumps(item)
                 customer = Customer.from_json(item)
                 customers.append(customer)
                 return (customers, meta)
@@ -302,7 +318,7 @@ class CustomersManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             customer = Customer.from_json(data)
             return customer
         else:
@@ -330,7 +346,7 @@ class CustomersManager(Manager):
 
         status, message = self.get_content_status(content)
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             return Customer.from_json(data)
         else:
             raise APIConnectionFailedError(message)
@@ -366,7 +382,7 @@ class CustomersManager(Manager):
             status, message = self.get_content_status(content)
 
             if status:
-                data = json.JSONEncoder().encode(content['data'])
+                data = json.dumps(content['data'])
                 return Customer.from_json(data)
             else:
                 raise APIConnectionFailedError(message)
@@ -430,7 +446,7 @@ class PlanManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             return Plan.from_json(data)
         else:
             raise APIConnectionFailedError(message)
@@ -452,7 +468,7 @@ class PlanManager(Manager):
             meta = content['meta']
             plans = []
             for item in data:
-                item = json.JSONEncoder().encode(item)
+                item = json.dumps(item)
                 plan = Plan.from_json(item)
                 plans.append(plan)
                 return (plans, meta)
@@ -474,7 +490,7 @@ class PlanManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             plan = Plan.from_json(data)
             return plan
         else:
@@ -497,7 +513,7 @@ class PlanManager(Manager):
 
         status, message = self.get_content_status(content)
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             return Plan.from_json(data)
         else:
             raise APIConnectionFailedError(message)
@@ -534,7 +550,7 @@ class TransfersManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             transfer = Transfer.from_json(data)
             return transfer
 
@@ -560,7 +576,7 @@ class TransfersManager(Manager):
             data = content['data']
             transfers = []
             for item in data:
-                item = json.JSONEncoder().encode(item)
+                item = json.dumps(item)
                 transfers.append(Transfer.from_json(item))
 
             return transfers
@@ -584,7 +600,7 @@ class TransfersManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = json.JSONEncoder().encode(content['data'])
+            data = json.dumps(content['data'])
             return Transfer.from_json(data)
         else:
             #Connection failed
